Continued:
[core.git] / index.php
index ecf66b48876f5635b4848a966b756595673f1fec..1e7f1d48f75e9a68e0803bef7bd71d416ff24fa6 100644 (file)
--- a/index.php
+++ b/index.php
@@ -1,14 +1,15 @@
 <?php
 // Own namespace (watch out: core)
-namespace CoreFramework\EntryPoint;
+namespace Org\Mxchange\CoreFramework\EntryPoint;
 
 // Import framework stuff
-use CoreFramework\Configuration\FrameworkConfiguration;
-use CoreFramework\Factory\ObjectFactory;
-use CoreFramework\Helper\Application\ApplicationHelper;
-use CoreFramework\Localization\LanguageSystem;
-use CoreFramework\Loader\ClassLoader;
-use CoreFramework\Generic\FrameworkException;
+use Org\Mxchange\CoreFramework\Bootstrap\FrameworkBootstrap;
+use Org\Mxchange\CoreFramework\Factory\ObjectFactory;
+use Org\Mxchange\CoreFramework\Filesystem\FileNotFoundException;
+use Org\Mxchange\CoreFramework\Helper\Application\ApplicationHelper;
+use Org\Mxchange\CoreFramework\Localization\LanguageSystem;
+use Org\Mxchange\CoreFramework\Loader\ClassLoader;
+use Org\Mxchange\CoreFramework\Generic\FrameworkException;
 
 // Import SPL stuff
 use \Exception;
@@ -23,7 +24,7 @@ use \Exception;
  *
  * @author             Roland Haeder <webmaster@shipsimu.org>
  * @version            0.0.0
- * @copyright  Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Core Developer Team
+ * @copyright  Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
  * @license            GNU GPL 3.0 or any newer version
  * @link               http://www.shipsimu.org
  *
@@ -56,7 +57,7 @@ final class ApplicationEntryPoint {
         * @return      void
         * @todo        This method is old code and needs heavy rewrite and should be moved to ApplicationHelper
         */
-       public static final function app_exit ($message = '', $code = FALSE, $extraData = '', $silentMode = FALSE) {
+       public static final function exitApplication ($message = '', $code = false, $extraData = '', $silentMode = false) {
                // Is this method already called?
                if (isset($GLOBALS['app_die_called'])) {
                        // Then output the text directly
@@ -64,7 +65,7 @@ final class ApplicationEntryPoint {
                } // END - if
 
                // This method shall not be called twice
-               $GLOBALS['app_die_called'] = TRUE;
+               $GLOBALS['app_die_called'] = true;
 
                // Is a message set?
                if (empty($message)) {
@@ -73,23 +74,23 @@ final class ApplicationEntryPoint {
                } // END - if
 
                // Get config instance
-               $configInstance = FrameworkConfiguration::getSelfInstance();
+               $configInstance = FrameworkBootstrap::getConfigurationInstance();
 
                // Do we have debug installation?
-               if (($configInstance->getConfigEntry('product_install_mode') == 'productive') || ($silentMode === TRUE)) {
+               if (($configInstance->getConfigEntry('product_install_mode') == 'productive') || ($silentMode === true)) {
                        // Abort here
                        exit();
                } // END - if
 
                // Get some instances
-               $tpl = FrameworkConfiguration::getSelfInstance()->getConfigEntry('html_template_class');
+               $tpl = $configInstance->getConfigEntry('html_template_class');
                $languageInstance = LanguageSystem::getSelfInstance();
 
                // Initialize template instance here to avoid warnings in IDE
                $templateInstance = NULL;
 
                // Get response instance
-               $responseInstance = ApplicationHelper::getSelfInstance()->getResponseInstance();
+               $responseInstance = FrameworkBootstrap::getResponseInstance();
 
                // Is the template engine loaded?
                if ((class_exists($tpl)) && (is_object($languageInstance))) {
@@ -98,7 +99,7 @@ final class ApplicationEntryPoint {
                                // Get the template instance from our object factory
                                $templateInstance = ObjectFactory::createObjectByName($tpl);
                        } catch (FrameworkException $e) {
-                               exit(sprintf("[Main:] Could not initialize template engine for reason: <span class=\"exception_reason\">%s</span>",
+                               exit(sprintf('[Main:] Could not initialize template engine for reason: <span class="exception_reason">%s</span>',
                                        $e->getMessage()
                                ));
                        }
@@ -119,7 +120,7 @@ final class ApplicationEntryPoint {
                                } // END - if
 
                                // Add the traceback path to the final output
-                               $backtrace .= sprintf("<span class=\"backtrace_file\">%s</span>:%d, <span class=\"backtrace_function\">%s(%d)</span><br />\n",
+                               $backtrace .= sprintf('<span class="backtrace_file">%s</span>:%d, <span class="backtrace_function">%s(%d)</span><br />' . PHP_EOL,
                                        basename($trace['file']),
                                        $trace['line'],
                                        $trace['function'],
@@ -131,7 +132,7 @@ final class ApplicationEntryPoint {
                        $applicationInstance = NULL;
 
                        // Is the class there?
-                       if (class_exists('CoreFramework\Helper\Application\ApplicationHelper')) {
+                       if (class_exists('Org\Mxchange\CoreFramework\Helper\Application\ApplicationHelper')) {
                                // Get application instance
                                $applicationInstance = ApplicationHelper::getSelfInstance();
 
@@ -191,35 +192,32 @@ final class ApplicationEntryPoint {
                // Is it not set?
                if (empty(self::$frameworkPath)) {
                        // Auto-detect core path (first application-common)
-                       foreach (array('core', '.', '/usr/local/share/php/core', '/usr/share/php/core') as $possiblePath) {
+                       foreach (array('core', __DIR__, '/usr/local/share/php/core', '/usr/share/php/core') as $possiblePath) {
                                // Create full path for testing
                                $realPath = realpath($possiblePath);
 
                                // Debug message
                                //* NOISY-DEBUG: */ printf('[%s:%d]: realPath[%s]=%s' . PHP_EOL, __METHOD__, __LINE__, gettype($realPath), $realPath);
 
-                               // Is it FALSE?
-                               if ($realPath === FALSE) {
+                               // Is it false?
+                               if ($realPath === false) {
                                        // Then, not found.
                                        continue;
                                } // END - if
 
-                               // First create full-qualified file name (FQFN) to framework/config.inc.php
-                               $fqfn = sprintf(
-                                       '%s%sframework%sconfig.inc.php',
-                                       $realPath,
-                                       DIRECTORY_SEPARATOR,
-                                       DIRECTORY_SEPARATOR,
-                                       $possiblePath
-                               );
+                               // Append framework path
+                               $frameworkPath = sprintf('%s%sframework%s', $realPath, DIRECTORY_SEPARATOR, DIRECTORY_SEPARATOR);
+
+                               // First create full-qualified file name (FQFN) to framework/config-global.php
+                               $configFile = $frameworkPath . 'config-global.php';
 
                                // Debug message
-                               /* NOISY-DEBUG: */ printf('[%s:%d]: fqfn=%s' . PHP_EOL, __METHOD__, __LINE__, $fqfn);
+                               //* NOISY-DEBUG: */ printf('[%s:%d]: configFile=%s' . PHP_EOL, __METHOD__, __LINE__, $configFile);
 
                                // Is it readable?
-                               if (is_readable($fqfn)) {
+                               if (is_readable($configFile)) {
                                        // Found one
-                                       self::$frameworkPath = $realPath . '/framework/';
+                                       self::$frameworkPath = $frameworkPath;
 
                                        // Abort here
                                        break;
@@ -237,6 +235,16 @@ final class ApplicationEntryPoint {
                return self::$frameworkPath;
        }
 
+       /**
+        * Getter for root path
+        *
+        * @return      $rootPath       Root path
+        */
+       public static function getRootPath () {
+               // Get __DIR__, really simple and no detection
+               return __DIR__;
+       }
+
        /**
         * The framework's main entry point. This class isolates some local
         * variables which shall not become visible to outside because of security
@@ -247,18 +255,30 @@ final class ApplicationEntryPoint {
         */
        public static final function main () {
                // Load bootstrap file
-               require(self::detectFrameworkPath() . 'bootstrap/bootstrap.inc.php');
-
-               // Get a new configuration instance
-               $cfg = FrameworkConfiguration::getSelfInstance();
+               require sprintf('%sbootstrap%sbootstrap.inc.php', self::detectFrameworkPath(), DIRECTORY_SEPARATOR);
+
+               /*
+                * Initial bootstrap is done, continue with initialization of
+                * framework.
+                */
+               FrameworkBootstrap::initFramework();
+
+               // Next initialize the detected application
+               FrameworkBootstrap::prepareApplication();
+
+               /*
+                * Last step is to start the application, this will also initialize and
+                * register the application instance in registry.
+                */
+               FrameworkBootstrap::startApplication();
        }
 }
 
 // Developer mode active? Comment out if no dev!
-define('DEVELOPER', TRUE);
+define('DEVELOPER', true);
 
 // Log all exceptions (only debug! This option can create large error logs)
-//define('LOG_EXCEPTIONS', TRUE);
+//define('LOG_EXCEPTIONS', true);
 
 //xdebug_start_trace();